from oerppy import model
from oerppy.addons import project


class UserCategory(model.Model):
    """
    This is an object model that maps to search results from the custom OpenERP
    "canonical.user.category" entity.
    """
    def __init__(self, row):
        self.id = row.get("id")
        self.code = row.get("code")
        self.name = row.get("name")
        self.complete_name = row.get("complete_name")
        self.child_ids = row.get("child_ids")
        self.user_ids = row.get("user_ids")
        self.parent_left = row.get("parent_left")
        self.parent_right = row.get("parent_right")
        self.active = row.get("active")
        # The following are key/value pairs, each with .key and .value
        # attributes
        self.parent_id = model.KeyValuePairField(row.get("parent_id")) 


class UserCategoriesSet(model.ResultSet):
    """
    An object for collecting UserCategory records together.
    """
    model = UserCategory



class TaskWork(project.model.TaskWork):
    """
    This is an object model that maps to search results from the customized
    OpenERP "project.task.work" entity.
    """
    def __init__(self, row, depts):
        super(TaskWork, self).__init__(row, depts)
        self.project = model.KeyValuePairField(row.get("project_id"))
        self.week_start = row.get("week_start")


class TaskWorkSet(project.model.TaskWorkSet):
    """
    An object for collecting TaskWork records together.
    """
    model = TaskWork

    def get_work(self, project_id):
        for project in self:
            if project.project.key == project_id:
                return project


class User(model.User):
    """
    This is an object model that maps to search results from the customized
    OpenERP "res.users" entity.
    """
    def __init__(self, row):
        super(User, self).__init__(row)
        self.category_ids = row.get("category_ids")


class UsersSet(model.UsersSet):
    """
    An object for collecting User records together.
    """
    model = User
