import unittest

from oerppy.addons import hr
from oerppy.addons.hr.tests.test_model import employee_results
from oerppy.addons.canonical import model


class ProjectTaskWorkTestCase(unittest.TestCase):

    def setUp(self):
        self.work_results = [
            {"project_id": [1, "Manhattan"],
             "task_id": [1001, "Figure out Atoms"],
             "user_id": [314, "Alice"],
             "hours": 273,
             "department_id": [1, "Crypto"],
             "date": "2011-05-01",
             "week_start": 172},
            {"project_id": [2, "Turing"],
             "task_id": [1002, "Build a von Nuemann machine"],
             "user_id": [315, "Bob"],
             "hours": 735,
             "department_id": [2, "Maths"],
             "date": "2011-05-01",
             "week_start": 172},
            ]
        self.results = hr.model.EmployeeSet(employee_results)
        self.table = self.results.build_department_lookup_table()

    def test_project_task_work(self):

        work = model.TaskWork(self.work_results[1], self.table)
        self.assertEqual(work.project.key, 2)
        self.assertEqual(work.project.value, "Turing")
        self.assertEqual(work.task.key, 1002)
        self.assertEqual(work.user.key, 315)
        self.assertEqual(work.department_name, "Maths")
        self.assertEqual(work.hours, 735)
        self.assertEqual(work.date, "2011-05-01")
        self.assertEqual(work.year, 2011)
        self.assertEqual(work.month, 5)
        self.assertEqual(work.week_start, 172)

    def test_project_task_work_set(self):
        results = model.TaskWorkSet(self.work_results, self.table)
        self.assertEqual(len(results), 2)
        work = results.get_work(1)
        self.assertEqual(work.hours, 273)

