from oerppy import model


class Employee(model.Model):
    """
    This is an object model that maps to search results from OpenERP's
    "hr.employee" entity.
    """
    def __init__(self, row):
        self.id = row.get("id")
        self.name = row.get("name")
        self.work_email = row.get("work_email")
        self.active = row.get("active")
        self.resource_type = row.get("resource_type")
        self.child_ids = row.get("child_ids")
        self.time_efficiency = row.get("time_efficiency")
        self.state = row.get("state")
        self.gender = row.get("gender")
        self.photo = row.get("photo")
        # The following are key/value pairs, each with .key and .value
        # attributes
        self.user = model.KeyValuePairField(row.get("user_id"))
        self.resource = model.KeyValuePairField(row.get("resource_id"))
        self.department = model.KeyValuePairField(row.get("department_id")) 
        self.address = model.KeyValuePairField(row.get("address_id"))
        self.country = model.KeyValuePairField(row.get("country_id")) 
        self.company = model.KeyValuePairField(row.get("company_id")) 
        self.parent = model.KeyValuePairField(row.get("parent_id"))
        self.product = model.KeyValuePairField(row.get("product_id"))
        self.journal = model.KeyValuePairField(row.get("journal_id"))
        # XXX I haven't used these; they need to be checked by someone who has
        # and then given the appropriate field class.
        # XXX I'm assuming these would just be simple values:
        self.code = None
        self.marital = None
        self.sinid = None
        self.work_phone = None
        self.category_ids = None
        self.mobile_phone = None
        self.birthday = None
        self.work_location = None
        self.notes = None
        self.ssnid = None
        # XXX I'm assuming these would be key-value pairs:
        self.coach_id = None
        self.identification_id = None
        self.partner_id = None
        self.job_id = None
        self.bank_account_id = None
        self.calendar_id = None
        self.address_home_id = None
        self.passport_id = None


class EmployeeSet(model.ResultSet):
    """
    An object for collecting HREmployees together.
    """
    model = Employee

    def get_user(self, user_id):
        for employee in self:
            if employee.user.key == user_id:
                return employee

    def build_department_lookup_table(self):
        table = {}
        table["unknown"] = 0
        for employee in self:
            if employee.department and employee.user.key:
                table[employee.user.key] = employee.department.value
            elif employee.user.key:
                table[employee.user.key] = "?"
            else:
                table["unknown"] += 1
        return table

