from oerppy import model


class Project(model.Model):
    """
    This is an object model that maps to search results from OpenERP's
    "project.project" entity.
    """
    def __init__(self, row):
        self.id = row.get("id")
        self.code = row.get("code")
        self.name = row.get("name")
        self.sequence = row.get("sequence")
        self.date = row.get("date")
        self.tasks = row.get("tasks")
        self.warn_footer = row.get("warn_footer")
        self.warn_manager = row.get("warn_manager")
        self.to_invoice = row.get("to_invoice")
        self.warn_customer = row.get("warn_customer")
        self.date_start = row.get("date_start")
        self.priority = row.get("priority")
        self.state = row.get("state")
        self.complete_name = row.get("complete_name")
        self.type = row.get("type")
        self.description = row.get("description")
        self.child_ids = row.get("child_ids")
        self.members = row.get("members")
        self.active = row.get("active")
        self.child_complete_ids = row.get("child_complete_ids")
        self.warn_header = row.get("warn_header")
        self.line_ids = row.get("line_ids")
        self.type_ids = row.get("type_ids")
        self.analytic_account_id = row.get("analytic_account_id")
        # The following are key/value pairs, each with .key and .value
        # attributes
        self.contact_id = model.KeyValuePairField(row.get("contact_id"))
        self.currency_id = model.KeyValuePairField(row.get("currency_id"))
        self.company_id = model.KeyValuePairField(row.get("company_id"))
        self.parent_id = model.KeyValuePairField(row.get("parent_id"))
        self.pricelist_id = model.KeyValuePairField(row.get("pricelist_id"))
        self.user_id = model.KeyValuePairField(row.get("user_id"))
        self.partner_id = model.KeyValuePairField(row.get("partner_id"))
        # The following are computed attributes
        self.amount_invoiced = float(row.get("amount_invoiced", 0))
        self.amount_max = float(row.get("amount_max", 0))
        self.debit = float(row.get("debit", 0))
        self.credit = float(row.get("credit", 0))
        self.balance = float(row.get("balance", 0))
        self.effective_hours = float(row.get("effective_hours", 0))
        self.total_hours = float(row.get("total_hours", 0)) 
        self.planned_hours = float(row.get("planned_hours", 0))
        self.progress_rate = float(row.get("progress_rate", 0))
        self.quantity = float(row.get("quantity", 0))
        self.quantity_max = float(row.get("quantity_max", 0))


class ProjectSet(model.ResultSet):
    """
    An object for collecting Project records together.
    """
    model = Project


class TaskWork(model.Model):
    """
    This is an object model that maps to search results from OpenERP's
    "project.task.work" entity.
    """
    def __init__(self, row, depts):
        self.hours = row.get("hours")
        self.date = row.get("date")
        self.week_start = row.get("week_start")
        # The following are key/value pairs, each with .key and .value
        # attributes
        self.project = model.KeyValuePairField(row.get("project_id"))
        self.task = model.KeyValuePairField(row.get("task_id"))
        self.user = model.KeyValuePairField(row.get("user_id"))
        # The following are computed attributes
        if self.date:
            self.year = int(self.date[0:4])
            self.month = int(self.date[5:7])
        else:
            self.year = None
            self.month = None
        self.department_name = depts.get(self.user.key)


class TaskWorkSet(model.ResultSet):
    """
    An object for collecting TaskWork records together.
    """
    model = TaskWork


class TimeEntryProjectData(object):
    """
    A simple object class for storying time-entry project data.
    """
    def __init__(self, project, task, work, hours):
        self.project = project
        self.task = task
        self.work = work
        self.hours = hours

    def __repr__(self):
        return str(self.__dict__)


class TimeEntry(model.Model):
    """
    This is an object model that maps to search results from OpenERP's
    "project.timeentry" entity.
    """
    def __init__(self, row):
        self.id = row.get("id")
        self.week_start = row.get("week_start")
        self.submitted_date = row.get("submitted")
        self.state = row.get("state")
        self.projects = []
        # The following are key/value pairs, each with .key and .value
        # attributes 
        self.user = model.KeyValuePairField(row.get("user_id"))

        for index in xrange(1, 11):
            project_key = "project%s_id" % index
            task_key = "task%s_id" % index
            work_key = "work%s_id" % index
            hours_key = "hours%s_id" % index
            data = TimeEntryProjectData(
                model.KeyValuePairField(row.get(project_key)),
                model.KeyValuePairField(row.get(task_key)),
                model.KeyValuePairField(row.get(work_key)),
                float(row.get(hours_key, 0)))
            self.projects.append(data)

        self.total_time = float(row.get("total_time", 0))


class TimeEntrySet(model.ResultSet):
    """
    An object for collecting TimeEntry records together.
    """
    model = TimeEntry


class TimeEntryWeek(model.Model):
    """
    This is an object model that maps to search results from OpenERP's
    "project.timeentry.week" entity.
    """
    def __init__(self, row):
        self.id = row.get("id")
        self.date = row.get("week")


class TimeEntryWeekSet(model.ResultSet):
    """
    An object for collecting TimeEntryWeek records together.
    """
    model = TimeEntryWeek
