from oerppy import model


class Query(object):
    """
    A wrapper class for RPC requests (queries) that are more
    involved/complicated than the ones implemented in the client class.

    AddOn classes use this as a base class.
    """
    def __init__(self, client):
        """
        Query classes should only need access to the client object, since
        through it, one will have access to all the endpoints, the dbname, the
        credentials, and the basic client query methods.
        """
        self.client = client

    def query(self, report, domains=None):
        """
        A dispatch method that each subclass needs to implement.
        """
        raise NotImplementedError

    def get_users(self):
        raw_results = self.client.searchfields(
            entity='res.users',
            query=[],
            fields=[])
        return model.UsersSet(raw_results)

    def get_user_names(self, user_ids):
        """
        Get the OpenERP user names for the user IDs provided.
        """
        raw_results = self.client.searchfields(
            'res.users' ,
            [('id','in', user_ids)],
            ['id', 'name'])
        return model.UsersSet(raw_results)
